@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include "importwizard.h"
 #include <KAboutData>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
-#include <KCrash>
 #include <QApplication>
 #include <QIcon>
-#include "importwizard.h"
 
 #include "importwizard-version.h"
 
@@ -29,23 +29,23 @@ int main(int argc, char *argv[])
     migrate.migrate();
 
     KLocalizedString::setApplicationDomain("akonadiimportwizard");
-    //FIXME: "wizards" are "assistents" in new KDE slang
+    // FIXME: "wizards" are "assistents" in new KDE slang
 
     KAboutData aboutData(QStringLiteral("importwizard"),
                          i18n("PIM Import Tool"),
                          QStringLiteral(KDEPIM_VERSION),
                          i18n("PIM Import Tool"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2012-2020 ImportWizard authors"));
+                         i18n("Copyright © 2012-2021 ImportWizard authors"));
 
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kontact-import-wizard")));
     aboutData.setOrganizationDomain(QByteArrayLiteral("kde.org"));
-    aboutData.setProductName(QByteArrayLiteral("importwizard"));
+    aboutData.setProductName(QByteArrayLiteral("kmail2/import wizard"));
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
-    parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("mode"), i18n("Mode: %1", QStringLiteral("manual|automatic"))));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("mode"), i18n("Mode: %1", QStringLiteral("manual|automatic"))));
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
